==> nextcloud-28.0.3.tgz: nextcloud/apps/comments/l10n/sl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Opombe",
    "You commented" : "Napišete opombo",
    "{author} commented" : "{author} vpiše opombo",
    "You commented on %1$s" : "Napišete opombo za %1$s",
    "You commented on {file}" : "Napišete opombo na {file}",
    "%1$s commented on %2$s" : "%1$s napiše opombo na %2$s",
    "{author} commented on {file}" : "{author} napiše opombo na {file}",
    "<strong>Comments</strong> for files" : "Vpisane so <strong>opombe</strong> k datotekam",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} vas omeni v opombi k datoteki »{file}«",
    "Files app plugin to add comments to files" : "Vstavek programa Datoteke za dodajanje opomb k datotekam",
    "Edit comment" : "Uredi opombo",
    "Delete comment" : "Izbriši opombo",
    "Cancel edit" : "Prekliči urejanje",
    "Post comment" : "Objavi opombo",
    "@ for mentions, : for emoji, / for smart picker" : "@ za omenjanje osebe, : za izris izraznih ikon, / za pametni izbirnik",
    "Could not reload comments" : "Opomb ni mogoče posodobiti",
    "No comments yet, start the conversation!" : "Ni še odzivov, bodite prvi!",
    "No more messages" : "Ni drugih sporočil",
    "Retry" : "Poskusi znova",
    "Failed to mark comments as read" : "Označevanje opomb kot prebranih je spodletelo",
    "Unable to load the comments list" : "Ni mogoče naložiti seznama opomb",
    "_1 new comment_::_{unread} new comments_" : ["{unread} nova opomba","{unread} novi opombi","{unread} nove opombe","{unread} novih opomb"],
    "Comment" : "Opomba",
    "An error occurred while trying to edit the comment" : "Prišlo je do napake med poskusom urejanja opombe",
    "Comment deleted" : "Opomba je izbrisana",
    "An error occurred while trying to delete the comment" : "Prišlo je do napake med brisanjem opombe",
    "An error occurred while trying to create the comment" : "Prišlo je do napake med ustvarjanjem opombe",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Uporabnik, ki je sicer že izbrisan, vas omeni v opombi k datoteki »{file}«.",
    "_%n unread comment_::_%n unread comments_" : ["%n  neprebrana opomba","%n  neprebrani opombi","%n  neprebrane opombe","%n neprebranih opomb"]
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-28.0.9.tgz: nextcloud/apps/comments/l10n/sl.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Opombe",
    "You commented" : "Napišete opombo",
    "{author} commented" : "{author} vpiše opombo",
    "You commented on %1$s" : "Napišete opombo za %1$s",
    "You commented on {file}" : "Napišete opombo na {file}",
    "%1$s commented on %2$s" : "%1$s napiše opombo na %2$s",
    "{author} commented on {file}" : "{author} napiše opombo na {file}",
    "<strong>Comments</strong> for files" : "Vpisane so <strong>opombe</strong> k datotekam",
    "Files" : "Datoteke s podpisi",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Uporabnik, ki je sicer že izbrisan, vas omenja v opombi k datoteki »{file}«.",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} vas omeni v opombi k datoteki »{file}«",
    "Files app plugin to add comments to files" : "Vstavek programa Datoteke za dodajanje opomb k datotekam",
    "Edit comment" : "Uredi opombo",
    "Delete comment" : "Izbriši opombo",
    "Cancel edit" : "Prekliči urejanje",
    "New comment" : "Nova opomba",
    "Write a comment …" : "Dopišite opombo ...",
    "Post comment" : "Objavi opombo",
    "@ for mentions, : for emoji, / for smart picker" : "@ za omenjanje osebe, : za izris izraznih ikon, / za pametni izbirnik",
    "Could not reload comments" : "Opomb ni mogoče posodobiti",
    "No comments yet, start the conversation!" : "Ni še odzivov, bodite prvi!",
    "No more messages" : "Ni drugih sporočil",
    "Retry" : "Poskusi znova",
    "Failed to mark comments as read" : "Označevanje opomb kot prebranih je spodletelo",
    "Unable to load the comments list" : "Ni mogoče naložiti seznama opomb",
    "_1 new comment_::_{unread} new comments_" : ["{unread} nova opomba","{unread} novi opombi","{unread} nove opombe","{unread} novih opomb"],
    "Comment" : "Opomba",
    "An error occurred while trying to edit the comment" : "Prišlo je do napake med poskusom urejanja opombe",
    "Comment deleted" : "Opomba je izbrisana",
    "An error occurred while trying to delete the comment" : "Prišlo je do napake med brisanjem opombe",
    "An error occurred while trying to create the comment" : "Prišlo je do napake med ustvarjanjem opombe",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Uporabnik, ki je sicer že izbrisan, vas omeni v opombi k datoteki »{file}«."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
